Bubble class

气泡组件 Bubble component

Inheritance
Available extensions

Constructors

Bubble({Key? key, required Widget child, double radius = 8, double arrowWidth = 12, double arrowHeight = 8, double arrowPositionPercent = 0.5, BubbleArrowDirection direction = BubbleArrowDirection.top, BubbleArrowShape arrowShape = BubbleArrowShape.triangle, bool arrowAdaptive = true, BoxDecoration? decoration, Clip clipBehavior = Clip.none})
const

Properties

arrowAdaptive bool
箭头大小是否自适应 / Arrow size adaptive 默认值: true 为true时箭头会自动避开圆角区域
final
arrowHeight double
箭头高度 / Arrow height 默认值: 8
final
arrowPositionPercent double
箭头位置偏移百分比 / Arrow position percent (0.0-1.0) 默认值: 0.5 (居中) 范围: 0.0-1.0
final
arrowShape BubbleArrowShape
箭头形状 / Arrow shape 默认值: BubbleArrowShape.triangle
final
arrowWidth double
箭头宽度 / Arrow width 默认值: 12
final
child Widget
子组件 / Child widget
final
clipBehavior Clip
裁剪行为 / Clip behavior 默认值: Clip.none
final
decoration BoxDecoration?
气泡装饰器 / Bubble decoration 支持颜色、渐变、边框、阴影等
final
direction BubbleArrowDirection
箭头方向 / Arrow direction 默认值: BubbleArrowDirection.top
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
radius double
圆角半径 / Border radius 默认值: 8
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) Blur

Available on Widget, provided by the BlurExtension extension

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited