FloatExpendButton class

create_user: zhengzaihong email:1096877329@qq.com create_date: 2023/4/19 create_time: 13:44 describe: 用于悬浮伸展菜单

Inheritance
Available extensions

Constructors

FloatExpendButton({required dynamic callback(int index), required List<FloatButtonStyle> iconList, double? fabHeight = 30, double? tabSpace = 10, Color? mainTabBeginColor = Colors.transparent, Color? mainTabAfterColor = Colors.grey, AnimatedIconData? mainAnimatedIcon = AnimatedIcons.menu_close, double? iconSize = 15, Curve? curve = Curves.easeOut, Duration? duration = const Duration(milliseconds: 300), ButtonType? type = ButtonType.left, Widget? mainCollapseWidget, Widget? mainExpandWidget, Key? key})
const

Properties

callback → dynamic Function(int index)
final
curve Curve?
final
duration Duration?
final
fabHeight double?
final
hashCode int
The hash code for this object.
no setterinherited
iconList List<FloatButtonStyle>
final
iconSize double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mainAnimatedIcon AnimatedIconData?
final
mainCollapseWidget Widget?
final
mainExpandWidget Widget?
final
mainTabAfterColor Color?
final
mainTabBeginColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabSpace double?
final
type ButtonType?
final

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) Blur

Available on Widget, provided by the BlurExtension extension

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _FloatExpendState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited