CardOrientation enum

展示方向 / Display orientation

Inheritance
Available extensions

Values

left → const CardOrientation

向左展开 / Expand left

向右展开 / Expand right

bottom → const CardOrientation

向下展开 / Expand bottom

top → const CardOrientation

向上展开 / Expand top

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CardOrientation>
A constant List of the values in this enum, in order of their declaration.