StackCard class

Inheritance
Available extensions

Constructors

StackCard({Key? key, double width = 140, double height = 140, StackCardSelected? cardSelected, List<Widget> children = const <Widget>[], SlideType slideType = SlideType.horizontal, CardOrientation orientation = CardOrientation.bottom, Duration duration = const Duration(milliseconds: 300)})
const

Properties

cardSelected StackCardSelected?
卡片选择回调 / Card selection callback
final
children List<Widget>
子组件列表 / Children list
final
duration Duration
动画时长 / Animation duration
final
hashCode int
The hash code for this object.
no setterinherited
height double
卡片高度 / Card height
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
orientation CardOrientation
展示方向 / Display orientation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slideType SlideType
滑动类型 / Slide type
final
width double
卡片宽度 / Card width
final

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) Blur

Available on Widget, provided by the BlurExtension extension

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<StatefulWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited