CircularStrokeCap enum

圆形进度条端点样式 / Circular Stroke Cap Style

  • butt: 平头 / Flat
  • round: 圆头 / Round
  • square: 方头 / Square
Inheritance
Available extensions

Values

butt → const CircularStrokeCap
round → const CircularStrokeCap
square → const CircularStrokeCap

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeCap StrokeCap

Available on CircularStrokeCap, provided by the CircularStrokeCapExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CircularStrokeCap>
A constant List of the values in this enum, in order of their declaration.