leading property
前置组件 / Leading widget
显示在进度条左侧的组件 Widget displayed on the left side of progress bar
示例: Text('0%') / Example: Text('0%')
Implementation
final Widget? leading;
前置组件 / Leading widget
显示在进度条左侧的组件 Widget displayed on the left side of progress bar
示例: Text('0%') / Example: Text('0%')
final Widget? leading;