trailing property
后置组件 / Trailing widget
显示在进度条右侧的组件 Widget displayed on the right side of progress bar
示例: Text('100%') / Example: Text('100%')
Implementation
final Widget? trailing;
后置组件 / Trailing widget
显示在进度条右侧的组件 Widget displayed on the right side of progress bar
示例: Text('100%') / Example: Text('100%')
final Widget? trailing;