MultiSelector class

Inheritance
Available extensions

Constructors

MultiSelector({Key? key, required List<MultiSelectorEntity> data, required void onSelectionChanged(List<MultiSelectorEntity> list), required Widget buildItems(MultiSelectorEntity node, int level, bool isExpanded, bool hasChildren), MultiSelectorController? controller, String? accordionKey, bool animation = true, Duration animationDuration = const Duration(milliseconds: 300), Curve curve = Curves.easeInOut, AlignmentGeometry animationAlignment = Alignment.topLeft, List<String>? defaultSelected, bool completeCallback = true})
const

Properties

accordionKey → String?
final
animation → bool
final
animationAlignment → AlignmentGeometry
final
animationDuration → Duration
final
buildItems → Widget Function(MultiSelectorEntity node, int level, bool isExpanded, bool hasChildren)
final
completeCallback → bool
final
controller → MultiSelectorController?
final
curve → Curve
final
data → List<MultiSelectorEntity>
final
defaultSelected → List<String>?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSelectionChanged → void Function(List<MultiSelectorEntity> list)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) → Blur

Available on Widget, provided by the BlurExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → MultiSelectorState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) → Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited