SelectableController class
控制器:用于外部主动控制选中状态
- Inheritance
-
- Object
- ChangeNotifier
- SelectableController
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- multiple ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selected
→ List<
int> -
no setter
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
bind(
_SelectableGroupState state) → void -
clear(
) → void -
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
onTap(
int index) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
reset(
List< int> defaults) → void -
select(
int index) → void - 外部接口
-
selectAll(
int itemCount) → void -
toggle(
int index) → void -
toString(
) → String -
A string representation of this object.
inherited
-
unselect(
int index) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited