SelectableLayout enum

create_user: zhengzaihong email:1096877329@qq.com create_date: 2025-10-23 create_time: 17:59 describe: 支持的布局类型

Inheritance
Available extensions

Values

column → const SelectableLayout
row → const SelectableLayout
wrap → const SelectableLayout
grid → const SelectableLayout

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SelectableLayout>
A constant List of the values in this enum, in order of their declaration.