SelectionMenuForm<T> class

Inheritance
Available extensions

Constructors

SelectionMenuForm({required WidgetBuilder selectorBuilder, required DropDownButtonBuilder? buttonBuilder, SelectionMenuFormController? controller, LayoutSelectPop? layoutSelectPop, DropDownPopCreated? onCreated, DropDownPopShow? onShow, DropDownPopDismiss? onDismiss, bool enableOnHover = false, bool enableClick = true, bool matchParentWidth = true, double popWidth = 0, double hMargin = 0, double vMargin = 0, double popHeight = 200, BorderRadiusGeometry? materialBorderRadius, Color? color = Colors.transparent, ShapeBorder? shape, double elevation = 0.0, Color? shadowColor, String? barrierLabel, Color? barrierColor, bool barrierDismissible = true, Duration transitionDuration = const Duration(milliseconds: 200), AlignType alignType = AlignType.left, GestureTapCallback? onDoubleTap, GestureLongPressCallback? onLongPress, GestureTapDownCallback? onTapDown, GestureTapUpCallback? onTapUp, GestureTapCancelCallback? onTapCancel, ValueChanged<bool>? onHighlightChanged, ValueChanged<bool>? onHover, MouseCursor? mouseCursor, Color? focusColor, Color? hoverColor, Color? highlightColor, WidgetStateProperty<Color?>? overlayColor, Color? splashColor, InteractiveInkFeatureFactory? splashFactory, double? radius, BorderRadius? borderRadius, ShapeBorder? customBorder, bool enableFeedback = true, bool excludeFromSemantics = false, FocusNode? focusNode, bool canRequestFocus = true, ValueChanged<bool>? onFocusChange, bool autofocus = false, AutovalidateMode? autovalidateMode, ScrollController? scrollController, String? restorationId, FormFieldSetter? onSaved, FormFieldValidator? validator, bool? enabled, required ValueNotifier<FormTips> valueNotifier, Widget? noneTips, Widget? warningTips, Widget? errorTips, InputDecoration decoration = const InputDecoration(), Key? key})

Properties

alignType → AlignType
对齐方式
final
autofocus → bool
final
autovalidateMode → AutovalidateMode
Used to enable/disable this form field auto validation and update its error text.
finalinherited
barrierColor → Color?
final
barrierDismissible → bool
是否允许点击其他区域消失
final
barrierLabel → String?
final
borderRadius → BorderRadius?
final
builder → FormFieldBuilder<T>
Function that returns the widget representing this form field.
finalinherited
buttonBuilder → DropDownButtonBuilder?
下拉框构建器
final
canRequestFocus → bool
final
color → Color?
final
controller → SelectionMenuFormController?
final
customBorder → ShapeBorder?
final
elevation → double
阴影
final
enableClick → bool
是否开启点击
final
enabled → bool
Whether the form is able to receive user input.
finalinherited
enableFeedback → bool
final
enableOnHover → bool
是否开启鼠标悬浮
final
errorBuilder → FormFieldErrorBuilder?
Function that returns the widget representing the error to display.
finalinherited
excludeFromSemantics → bool
final
focusColor → Color?
final
focusNode → FocusNode?
final
forceErrorText → String?
An optional property that forces the FormFieldState into an error state by directly setting the FormFieldState.errorText property without running the validator function.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
highlightColor → Color?
final
hMargin → double
水平边距
final
hoverColor → Color?
final
initialValue → T?
An optional value to initialize the form field to, or null otherwise.
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
layoutSelectPop → LayoutSelectPop?
自定义下拉框位置
final
matchParentWidth → bool
当设置的宽度小于 父组件宽度时, 是否匹配父组件宽度,默认true
final
materialBorderRadius → BorderRadiusGeometry?
Material 背景样式
final
mouseCursor → MouseCursor?
final
onCreated → DropDownPopCreated?
下拉框创建
final
onDismiss → DropDownPopCreated?
下拉框消失
final
onDoubleTap → GestureTapCallback?
final
onFocusChange → DropDownPopCreated?
final
onHighlightChanged → DropDownPopCreated?
final
onHover → DropDownPopCreated?
final
onLongPress → GestureTapCallback?
final
onReset → GestureTapCallback?
An optional method to call when the form field is reset via FormFieldState.reset.
finalinherited
onSaved → FormFieldSetter<T>?
An optional method to call with the final value when the form is saved via FormState.save.
finalinherited
onShow → DropDownPopCreated?
下拉框显示
final
onTapCancel → GestureTapCallback?
final
onTapDown → GestureTapDownCallback?
final
onTapUp → GestureTapUpCallback?
final
overlayColor → WidgetStateProperty<Color?>?
final
popHeight → double
窗口高度
final
popWidth → double
下拉框宽度 弹窗部分
final
radius → double?
final
restorationId → String?
Restoration ID to save and restore the state of the form field.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectorBuilder → WidgetBuilder
下拉框样式构件 弹出部分
final
shadowColor → Color?
阴影颜色
final
shape → ShapeBorder?
final
splashColor → Color?
final
splashFactory → InteractiveInkFeatureFactory?
final
transitionDuration → Duration
动画时间
final
validator → FormFieldValidator<T>?
An optional method that validates an input. Returns an error string to display if the input is invalid, or null otherwise.
finalinherited
vMargin → double
垂直 边距
final

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) → Blur

Available on Widget, provided by the BlurExtension extension

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → FormFieldState<T>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) → Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited