RowStyleParam<T> class

构建每一行的参数

Constructors

RowStyleParam({T? data, double? rowWidth, List<double>? cellWidth, List<double>? cellFlex, double? minCellWidth, int? index, bool enableDivider = false})

Properties

cellFlex List<double>?
列权重(与 TableExtend.cellWidthFlex / fixCellHeaderWidthFlex / fixCellFootWidthFlex 对应) 用于更“Table 风格”的按比例分配宽度。
getter/setter pair
cellWidth List<double>?
单元格宽度
getter/setter pair
data ↔ T?
getter/setter pair
effectiveCellWidth List<double>
根据当前 rowWidth 与列权重计算的“最终展示宽度”(优先按权重占比)。
no setter
enableDivider bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
index int?
getter/setter pair
minCellWidth double?
TableExtend.minCellWidth(用于兼容旧逻辑/外部计算需要)
getter/setter pair
rowWidth double?
行高
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited