build method
Describes the part of the user interface represented by this widget.
The framework calls this method when this widget is inserted into the tree in a given BuildContext and when the dependencies of this widget change (e.g., an InheritedWidget referenced by this widget changes). This method can potentially be called in every frame and should not have any side effects beyond building a widget.
The framework replaces the subtree below this widget with the widget returned by this method, either by updating the existing subtree or by removing the subtree and inflating a new subtree, depending on whether the widget returned by this method can update the root of the existing subtree, as determined by calling Widget.canUpdate.
Typically implementations return a newly created constellation of widgets that are configured with information from this widget's constructor and from the given BuildContext.
The given BuildContext contains information about the location in the tree at which this widget is being built. For example, the context provides the set of inherited widgets for this location in the tree. A given widget might be built with multiple different BuildContext arguments over time if the widget is moved around the tree or if the widget is inserted into the tree in multiple places at once.
The implementation of this method must only depend on:
- the fields of the widget, which themselves must not change over time, and
- any ambient state obtained from the
contextusing BuildContext.dependOnInheritedWidgetOfExactType.
If a widget's build method is to depend on anything else, use a StatefulWidget instead.
See also:
- StatelessWidget, which contains the discussion on performance considerations.
Implementation
@override
Widget build(BuildContext context) {
final spans = _normalizeSpans(children.length);
var widths = rowStyle.effectiveCellWidth;
// 当外部未配置列宽/权重时,降级为“均分整行宽度”,保证用法更接近 Flutter `Table`。
if (widths.isEmpty) {
final w = rowStyle.rowWidth;
if (w != null && w > 0 && children.isNotEmpty) {
final colCount = spans.fold<int>(0, (p, e) => p + e);
if (colCount > 0) {
widths = List<double>.filled(colCount, w / colCount);
}
}
}
assert(() {
final colCount = widths.length;
final spanSum = spans.fold<int>(0, (p, e) => p + e);
if (colCount != 0 && spanSum != colCount) {
throw FlutterError(
'TableExtendCells: colSpans 总和($spanSum)必须等于列数($colCount)。'
' 请调整 children 数量或 colSpans 配置。',
);
}
return true;
}());
int colIndex = 0;
final rowChildren = <Widget>[];
for (int i = 0; i < children.length; i++) {
final span = spans[i];
final w = _sumWidth(widths, colIndex, span);
rowChildren.add(SizedBox(width: w, child: children[i]));
colIndex += span;
}
return Row(
mainAxisAlignment: mainAxisAlignment,
mainAxisSize: mainAxisSize,
crossAxisAlignment: crossAxisAlignment,
textDirection: textDirection,
verticalDirection: verticalDirection,
children: rowChildren,
);
}