MarqueeView class

Inheritance
Available extensions

Constructors

MarqueeView({Key? key, required List marqueeItems, required BuildItem buildItem, MarqueeDirection direction = MarqueeDirection.horizontal, double itemExtent = 40, Duration interval = const Duration(seconds: 2), Duration animateDuration = const Duration(milliseconds: 600), double gap = 40, double speed = 0.5, bool loop = true, dynamic onIndexChange(int)?, bool enableFadeEdge = false, double fadeEdgeWidth = 30, double fadeEdgeHeight = 20})
const

Properties

animateDuration Duration
动画时长 / Animation duration
final
buildItem BuildItem
条目构建器 / Item builder
final
direction MarqueeDirection
滚动方向 / Scroll direction
final
enableFadeEdge bool
启用渐变边缘 / Enable fade edge
final
fadeEdgeHeight double
垂直渐变高度 / Vertical fade height
final
fadeEdgeWidth double
横向渐变宽度 / Horizontal fade width
final
gap double
横向间距 / Horizontal gap
final
hashCode int
The hash code for this object.
no setterinherited
interval Duration
显示间隔 / Display interval
final
itemExtent double
条目高度/容器高度 / Item height/Container height
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loop bool
是否循环 / Loop playback
final
marqueeItems List
数据源 / Data source
final
onIndexChange → dynamic Function(int)?
索引变化回调 / Index change callback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
横向滚动速度 / Horizontal scroll speed
final

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) Blur

Available on Widget, provided by the BlurExtension extension

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<MarqueeView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited