MarqueeViewController class

跑马灯控制器 / Marquee View Controller

用于外部控制跑马灯的暂停和恢复 Used to control pause and resume from outside

Constructors

MarqueeViewController()

Properties

hashCode int
The hash code for this object.
no setterinherited
isRunning bool
是否正在运行 / Is running
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause() → void
暂停滚动 / Pause scrolling
resume() → void
恢复滚动 / Resume scrolling
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited