ToastPosition enum

Toast的显示位置枚举 Toast display position enum

Inheritance
Available extensions

Values

center → const ToastPosition

居中显示 / Center position

bottom → const ToastPosition

底部显示 / Bottom position

top → const ToastPosition

顶部显示 / Top position

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ToastPosition>
A constant List of the values in this enum, in order of their declaration.