TimeView class

Inheritance
Available extensions

Constructors

TimeView({required int countdown, required _BuildChild? build, TimeViewController? controller, bool enableCancel = false, Duration duration = const Duration(seconds: 1), BuildCompleter? buildCompleter, BuildCompleter? onComplete, OnProgressCallback? onProgress, bool autoRestart = false, Key? key})
const

Properties

autoRestart bool
是否自动重启 / Auto restart
final
build → _BuildChild?
UI构建回调 / UI builder callback
final
buildCompleter BuildCompleter?
完成回调 / Completion callback
final
controller TimeViewController?
控制器 / Controller
final
countdown int
倒计时秒数 / Countdown seconds
final
duration Duration
时间单位 / Time unit
final
enableCancel bool
是否允许取消后重启 / Allow restart after cancel
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onComplete BuildCompleter?
完成回调(新) / Completion callback (new)
final
onProgress OnProgressCallback?
进度回调 / Progress callback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

blurred({double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) Blur

Available on Widget, provided by the BlurExtension extension

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<TimeView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
frosted({double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) Blur

Available on Widget, provided by the FrostExtension extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited