PagerTheme class
分页器主题配置 / Pager Theme Configuration
提供统一的分页器样式配置 Provides unified pager style configuration
Constructors
- PagerTheme({TextStyle? textStyle = const TextStyle(fontSize: 14, fontWeight: FontWeight.w400, color: Colors.black), Color pageIndicatorColor = Colors.grey, Color pageIndicatorActiveColor = Colors.black, Color checkedPageColor = Colors.black, BoxDecoration? checkedPageBoxDecoration, double pageTextSize = 14, double pageIndicatorHeight = 30, double borderRadius = 10, BoxBorder? focusBorder, TextStyle? inputTextStyle, TextStyle? inputHintTextStyle, Color? inputBgColor, OutlineInputTextBorder? outlineInputTextBorder = const OutlineInputTextBorder(borderSide: BorderSide(color: Colors.grey, width: 1.0), childBorderRadius: BorderRadius.all(Radius.circular(20))), EdgeInsetsGeometry? inputContentPadding = const EdgeInsets.symmetric(horizontal: 5, vertical: 5), double inputHeight = 30, double inputWidth = 50})
-
const
Properties
- borderRadius → double
-
边框圆角 / Border radius
final
- checkedPageBoxDecoration → BoxDecoration?
-
选中页码背景装饰 / Checked page box decoration
final
- checkedPageColor → Color
-
选中页码颜色 / Checked page color
final
- focusBorder → BoxBorder?
-
焦点边框 / Focus border
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputBgColor → Color?
-
输入框背景色 / Input background color
final
- inputContentPadding → EdgeInsetsGeometry?
-
输入框内边距 / Input content padding
final
- inputHeight → double
-
输入框高度 / Input height
final
- inputHintTextStyle → TextStyle?
-
输入框提示样式 / Input hint style
final
- inputTextStyle → TextStyle?
-
输入框样式 / Input style
final
- inputWidth → double
-
输入框宽度 / Input width
final
- outlineInputTextBorder → OutlineInputTextBorder?
-
输入框边框 / Input border
final
- pageIndicatorActiveColor → Color
-
页码指示器激活颜色 / Page indicator active color
final
- pageIndicatorColor → Color
-
页码指示器颜色 / Page indicator color
final
- pageIndicatorHeight → double
-
页码指示器高度 / Page indicator height
final
- pageTextSize → double
-
页码文本大小 / Page text size
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle?
-
文本样式 / Text style
final
Methods
-
copyWith(
{TextStyle? textStyle, Color? pageIndicatorColor, Color? pageIndicatorActiveColor, Color? checkedPageColor, BoxDecoration? checkedPageBoxDecoration, double? pageTextSize, double? pageIndicatorHeight, double? borderRadius, BoxBorder? focusBorder, TextStyle? inputTextStyle, TextStyle? inputHintTextStyle, Color? inputBgColor, OutlineInputTextBorder? outlineInputTextBorder, EdgeInsetsGeometry? inputContentPadding, double? inputHeight, double? inputWidth}) → PagerTheme - 复制并修改主题 / Copy with modifications
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- blueTheme ↔ PagerTheme
-
蓝色主题 / Blue theme
getter/setter pair
- darkTheme ↔ PagerTheme
-
暗色主题 / Dark theme
getter/setter pair
- greenTheme ↔ PagerTheme
-
绿色主题 / Green theme
getter/setter pair
Constants
- defaultTheme → const PagerTheme
- 默认主题 / Default theme