SelectableGroup class
主组件
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- SelectableGroup
- Available extensions
Constructors
-
SelectableGroup({Key? key, required int itemCount, required Widget itemBuilder(BuildContext context, int index, bool isSelected), bool multiple = false, dynamic defaultValue, bool enable = true, VoidCallback? onDisabledTap, void onSelectionChanged(List<
int> selected)?, int mutualExclusionIndex = -1, bool enableFirstTrigger = false, SelectableController? controller, SelectableLayout layout = SelectableLayout.column, double spacing = 8, double runSpacing = 8, int crossAxisCount = 2, double mainAxisSpacing = 10, double crossAxisSpacing = 10, double childAspectRatio = 1.2}) -
const
Properties
- childAspectRatio → double
-
final
- controller → SelectableController?
-
控制器
final
- crossAxisCount → int
-
Grid 参数
final
- crossAxisSpacing → double
-
final
- defaultValue → dynamic
-
默认选中
final
- enable → bool
-
是否可用
final
- enableFirstTrigger → bool
-
第一次触发回调
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → Widget Function(BuildContext context, int index, bool isSelected)
-
final
- itemCount → int
-
条目数
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- layout → SelectableLayout
-
布局模式
final
- mainAxisSpacing → double
-
final
- multiple → bool
-
是否支持多选
final
- mutualExclusionIndex → int
-
互斥索引
final
- onDisabledTap → VoidCallback?
-
点击不可用
final
-
onSelectionChanged
→ void Function(List<
int> selected)? -
选中回调
final
- runSpacing → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → double
-
Wrap 参数
final
Methods
-
blurred(
{double blur = 5, Color blurColor = Colors.white, BorderRadius? borderRadius, double colorOpacity = 0.5, Widget? overlay, AlignmentGeometry alignment = Alignment.center}) → Blur -
Available on Widget, provided by the BlurExtension extension
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< SelectableGroup> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
frosted(
{double blur = 5, Color frostColor = Colors.white, AlignmentGeometry alignment = Alignment.center, double? height, double? width, double frostOpacity = 0.0, BorderRadius? borderRadius, EdgeInsetsGeometry padding = EdgeInsets.zero}) → Blur -
Available on Widget, provided by the FrostExtension extension
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited