ToastAnimationConfig class
Toast 动画配置类 Toast animation configuration class
Constructors
Properties
- animationDuration → int
-
动画持续时间(毫秒)/ Animation duration (milliseconds)
默认值: 300ms
范围: 100-1000ms
final
- enableAnimation → bool
-
是否启用动画 / Enable animation
默认值: true
final
- enableScaleAnimation → bool
-
是否启用缩放动画 / Enable scale animation
默认值: true
final
- fadeInCurve → Curve
-
淡入动画曲线 / Fade in animation curve
默认值: Curves.easeOut
final
- fadeOutCurve → Curve
-
淡出动画曲线 / Fade out animation curve
默认值: Curves.easeIn
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scaleEnd → double
-
缩放动画结束值 / Scale animation end value
默认值: 1.0
final
- scaleStart → double
-
缩放动画起始值 / Scale animation start value
默认值: 0.8
范围: 0.0-1.0
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited