ToastStyleConfig class
Toast 样式配置类 Toast style configuration class
Constructors
-
ToastStyleConfig({EdgeInsetsGeometry margin = const EdgeInsets.only(left: 10, right: 10), EdgeInsetsGeometry padding = const EdgeInsets.fromLTRB(10, 15, 10, 15), AlignmentGeometry alignment = Alignment.topCenter, TextStyle textStyle = const TextStyle(decoration: TextDecoration.none, color: Colors.white, fontSize: 16), BoxDecoration decoration = const BoxDecoration(color: Colors.black38, borderRadius: BorderRadius.all(Radius.circular(30))), double? maxWidth, double? minWidth, List<
BoxShadow> ? boxShadow}) -
const
Properties
- alignment → AlignmentGeometry
-
对齐方式 / Alignment
默认值: Alignment.topCenter
final
-
boxShadow
→ List<
BoxShadow> ? -
阴影效果 / Box shadow
可选配置 / Optional configuration
final
- decoration → BoxDecoration
-
装饰样式 / Decoration style
默认值: BoxDecoration(color: Colors.black38, borderRadius: 30)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- margin → EdgeInsetsGeometry
-
外边距 / Outer margin
默认值: EdgeInsets.only(left: 10, right: 10)
final
- maxWidth → double?
-
最大宽度 / Maximum width
null 表示不限制 / null means no limit
final
- minWidth → double?
-
最小宽度 / Minimum width
默认值: 0
final
- padding → EdgeInsetsGeometry
-
内边距 / Inner padding
默认值: EdgeInsets.fromLTRB(10, 15, 10, 15)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textStyle → TextStyle
-
文本样式 / Text style
默认值: TextStyle(color: Colors.white, fontSize: 16)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited