CacheManagerImpl class
author:郑再红 email:1096877329@qq.com date: 2021/6/14 time: 16:10 describe: 缓存工具 - Web 平台实现
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
clearApplicationCache(
{dynamic docDirectory, dynamic tempDirectory}) → void - 删除缓存
-
deleteDirectory(
dynamic file) → Future< void> -
getTotalSizeOfFilesInDir(
dynamic file) → Future< double> - 获取当前文件大小
-
loadApplicationCache(
{dynamic docDirectory, dynamic tempDirectory}) → Future< double> - Web 平台使用浏览器存储,不支持文件系统
-
writeToFile(
dynamic documentsDir, String fileName, String notes, {String? direcName, String? userId = "user"}) → Future - Web 平台不支持文件系统写入