TimeViewController class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → TimeViewState?
-
no setter
Methods
-
bind(
TimeViewState state) → void -
cancelTimer(
) → void - 取消倒计时 / Cancel timer
-
dispose(
) → void -
getCurrentTime(
) → int - 获取当前剩余时间 / Get current remaining time
-
getProgress(
) → double - 获取当前进度 / Get current progress 返回值范围: 0.0-1.0 / Return range: 0.0-1.0
-
getRenderBox(
) → RenderBox? -
isPaused(
) → bool - 是否已暂停 / Is paused
-
isStart(
) → bool - 是否正在运行 / Is running
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pauseTimer(
) → void - 暂停倒计时 / Pause timer
-
resumeTimer(
) → void - 恢复倒计时 / Resume timer
-
startTimer(
) → void - 启动倒计时 / Start timer
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited